==> jc-1.4.0.tar.gz: java/security/cert/PKIXCertPathValidatorResult.h <==
// public class java.security.cert.PKIXCertPathValidatorResult

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e755c7543ee532d3 java_security_cert_PKIXCertPathValidatorResult

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_cert_PKIXCertPathValidatorResult_H_
#define _JC_java_security_cert_PKIXCertPathValidatorResult_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_PublicKey$object;
struct _jc_java_security_cert_PolicyNode$object;
struct _jc_java_security_cert_TrustAnchor$object;

// Typedefs
typedef struct _jc_java_security_cert_PKIXCertPathValidatorResult$sub_refs	_jc_java_security_cert_PKIXCertPathValidatorResult$sub_refs;
typedef struct _jc_java_security_cert_PKIXCertPathValidatorResult$sub_nonrefs	_jc_java_security_cert_PKIXCertPathValidatorResult$sub_nonrefs;
typedef struct _jc_java_security_cert_PKIXCertPathValidatorResult$refs	_jc_java_security_cert_PKIXCertPathValidatorResult$refs;
typedef struct _jc_java_security_cert_PKIXCertPathValidatorResult$nonrefs	_jc_java_security_cert_PKIXCertPathValidatorResult$nonrefs;
typedef struct _jc_java_security_cert_PKIXCertPathValidatorResult$object	_jc_java_security_cert_PKIXCertPathValidatorResult$object;

typedef const struct _jc_java_security_cert_PKIXCertPathValidatorResult$vmethods	_jc_java_security_cert_PKIXCertPathValidatorResult$vmethods;
typedef const struct _jc_java_security_cert_PKIXCertPathValidatorResult$vtable	_jc_java_security_cert_PKIXCertPathValidatorResult$vtable;
typedef const struct _jc_java_security_cert_PKIXCertPathValidatorResult$vtype	_jc_java_security_cert_PKIXCertPathValidatorResult$vtype;

// Constructors
extern void _jc_java_security_cert_PKIXCertPathValidatorResult$method$_init$3e39442dedc7fa50(_jc_env *, struct _jc_java_security_cert_PKIXCertPathValidatorResult$object *, struct _jc_java_security_cert_TrustAnchor$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_security_cert_PKIXCertPathValidatorResult$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_java_security_cert_PKIXCertPathValidatorResult$object *);
extern struct _jc_object *_jc_java_security_cert_PKIXCertPathValidatorResult$method$getPolicyTree$a2785cd473cde021(_jc_env *, struct _jc_java_security_cert_PKIXCertPathValidatorResult$object *);
extern struct _jc_object *_jc_java_security_cert_PKIXCertPathValidatorResult$method$getPublicKey$11feb83e68327d4d(_jc_env *, struct _jc_java_security_cert_PKIXCertPathValidatorResult$object *);
extern struct _jc_java_security_cert_TrustAnchor$object *_jc_java_security_cert_PKIXCertPathValidatorResult$method$getTrustAnchor$c875de9a500e8406(_jc_env *, struct _jc_java_security_cert_PKIXCertPathValidatorResult$object *);
extern struct _jc_java_lang_String$object *_jc_java_security_cert_PKIXCertPathValidatorResult$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_security_cert_PKIXCertPathValidatorResult$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_PKIXCertPathValidatorResult$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_java_security_cert_PKIXCertPathValidatorResult$method_info$getPolicyTree$a2785cd473cde021;
extern _jc_method _jc_java_security_cert_PKIXCertPathValidatorResult$method_info$getPublicKey$11feb83e68327d4d;
extern _jc_method _jc_java_security_cert_PKIXCertPathValidatorResult$method_info$getTrustAnchor$c875de9a500e8406;
extern _jc_method _jc_java_security_cert_PKIXCertPathValidatorResult$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_security_cert_PKIXCertPathValidatorResult$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_java_security_cert_PKIXCertPathValidatorResult$object *);
	struct _jc_object	*(*getPolicyTree$a2785cd473cde021)(_jc_env *, struct _jc_java_security_cert_PKIXCertPathValidatorResult$object *);
	struct _jc_object	*(*getPublicKey$11feb83e68327d4d)(_jc_env *, struct _jc_java_security_cert_PKIXCertPathValidatorResult$object *);
	struct _jc_java_security_cert_TrustAnchor$object	*(*getTrustAnchor$c875de9a500e8406)(_jc_env *, struct _jc_java_security_cert_PKIXCertPathValidatorResult$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_security_cert_PKIXCertPathValidatorResult$object *);
};

// Vtable
struct _jc_java_security_cert_PKIXCertPathValidatorResult$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_PKIXCertPathValidatorResult$vmethods	java_security_cert_PKIXCertPathValidatorResult;
};

// Vtype
struct _jc_java_security_cert_PKIXCertPathValidatorResult$vtype {
	_jc_type			type;
	_jc_java_security_cert_PKIXCertPathValidatorResult$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_PKIXCertPathValidatorResult$sub_refs {
	struct _jc_java_security_cert_TrustAnchor$object	*trustAnchor;
	struct _jc_object	*policyTree;
	struct _jc_object	*subjectPublicKey;
};

// Reference instance fields (object)
struct _jc_java_security_cert_PKIXCertPathValidatorResult$refs {
    _jc_java_security_cert_PKIXCertPathValidatorResult$sub_refs	java_security_cert_PKIXCertPathValidatorResult;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_PKIXCertPathValidatorResult$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_PKIXCertPathValidatorResult$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_PKIXCertPathValidatorResult$sub_nonrefs	java_security_cert_PKIXCertPathValidatorResult;
};

// Object instance structure
struct _jc_java_security_cert_PKIXCertPathValidatorResult$object {
	_jc_java_security_cert_PKIXCertPathValidatorResult$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_PKIXCertPathValidatorResult$vtype	*vtype;
	_jc_java_security_cert_PKIXCertPathValidatorResult$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_PKIXCertPathValidatorResult$vtype _jc_java_security_cert_PKIXCertPathValidatorResult$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_PKIXCertPathValidatorResult, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_PKIXCertPathValidatorResult$class_object;

#endif	/* _JC_java_security_cert_PKIXCertPathValidatorResult_H_ */

==> jc-1.4.6.tar.gz: java/security/cert/PKIXCertPathValidatorResult.h <==
// public class java.security.cert.PKIXCertPathValidatorResult

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e755c7543ee532d3 java_security_cert_PKIXCertPathValidatorResult

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_cert_PKIXCertPathValidatorResult_H_
#define _JC_java_security_cert_PKIXCertPathValidatorResult_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_PublicKey$object;
struct _jc_java_security_cert_PolicyNode$object;
struct _jc_java_security_cert_TrustAnchor$object;

// Typedefs
typedef struct _jc_java_security_cert_PKIXCertPathValidatorResult$sub_refs	_jc_java_security_cert_PKIXCertPathValidatorResult$sub_refs;
typedef struct _jc_java_security_cert_PKIXCertPathValidatorResult$sub_nonrefs	_jc_java_security_cert_PKIXCertPathValidatorResult$sub_nonrefs;
typedef struct _jc_java_security_cert_PKIXCertPathValidatorResult$refs	_jc_java_security_cert_PKIXCertPathValidatorResult$refs;
typedef struct _jc_java_security_cert_PKIXCertPathValidatorResult$nonrefs	_jc_java_security_cert_PKIXCertPathValidatorResult$nonrefs;
typedef struct _jc_java_security_cert_PKIXCertPathValidatorResult$object	_jc_java_security_cert_PKIXCertPathValidatorResult$object;

typedef const struct _jc_java_security_cert_PKIXCertPathValidatorResult$vmethods	_jc_java_security_cert_PKIXCertPathValidatorResult$vmethods;
typedef const struct _jc_java_security_cert_PKIXCertPathValidatorResult$vtable	_jc_java_security_cert_PKIXCertPathValidatorResult$vtable;
typedef const struct _jc_java_security_cert_PKIXCertPathValidatorResult$vtype	_jc_java_security_cert_PKIXCertPathValidatorResult$vtype;

// Constructors
extern void _jc_java_security_cert_PKIXCertPathValidatorResult$method$_init$3e39442dedc7fa50(_jc_env *, struct _jc_java_security_cert_PKIXCertPathValidatorResult$object *, struct _jc_java_security_cert_TrustAnchor$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_security_cert_PKIXCertPathValidatorResult$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_java_security_cert_PKIXCertPathValidatorResult$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_security_cert_PKIXCertPathValidatorResult$method$getPolicyTree$a2785cd473cde021(_jc_env *, struct _jc_java_security_cert_PKIXCertPathValidatorResult$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_security_cert_PKIXCertPathValidatorResult$method$getPublicKey$11feb83e68327d4d(_jc_env *, struct _jc_java_security_cert_PKIXCertPathValidatorResult$object *) _JC_JCNI_ATTR;
extern struct _jc_java_security_cert_TrustAnchor$object *_jc_java_security_cert_PKIXCertPathValidatorResult$method$getTrustAnchor$c875de9a500e8406(_jc_env *, struct _jc_java_security_cert_PKIXCertPathValidatorResult$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_security_cert_PKIXCertPathValidatorResult$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_security_cert_PKIXCertPathValidatorResult$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_PKIXCertPathValidatorResult$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_java_security_cert_PKIXCertPathValidatorResult$method_info$getPolicyTree$a2785cd473cde021;
extern _jc_method _jc_java_security_cert_PKIXCertPathValidatorResult$method_info$getPublicKey$11feb83e68327d4d;
extern _jc_method _jc_java_security_cert_PKIXCertPathValidatorResult$method_info$getTrustAnchor$c875de9a500e8406;
extern _jc_method _jc_java_security_cert_PKIXCertPathValidatorResult$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_security_cert_PKIXCertPathValidatorResult$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_java_security_cert_PKIXCertPathValidatorResult$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getPolicyTree$a2785cd473cde021)(_jc_env *, struct _jc_java_security_cert_PKIXCertPathValidatorResult$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getPublicKey$11feb83e68327d4d)(_jc_env *, struct _jc_java_security_cert_PKIXCertPathValidatorResult$object *) _JC_JCNI_ATTR;
	struct _jc_java_security_cert_TrustAnchor$object	*(*getTrustAnchor$c875de9a500e8406)(_jc_env *, struct _jc_java_security_cert_PKIXCertPathValidatorResult$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_security_cert_PKIXCertPathValidatorResult$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_cert_PKIXCertPathValidatorResult$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_PKIXCertPathValidatorResult$vmethods	java_security_cert_PKIXCertPathValidatorResult;
};

// Vtype
struct _jc_java_security_cert_PKIXCertPathValidatorResult$vtype {
	_jc_type			type;
	_jc_java_security_cert_PKIXCertPathValidatorResult$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_PKIXCertPathValidatorResult$sub_refs {
	struct _jc_java_security_cert_TrustAnchor$object	*trustAnchor;
	struct _jc_object	*policyTree;
	struct _jc_object	*subjectPublicKey;
};

// Reference instance fields (object)
struct _jc_java_security_cert_PKIXCertPathValidatorResult$refs {
    _jc_java_security_cert_PKIXCertPathValidatorResult$sub_refs	java_security_cert_PKIXCertPathValidatorResult;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_PKIXCertPathValidatorResult$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_PKIXCertPathValidatorResult$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_PKIXCertPathValidatorResult$sub_nonrefs	java_security_cert_PKIXCertPathValidatorResult;
};

// Object instance structure
struct _jc_java_security_cert_PKIXCertPathValidatorResult$object {
	_jc_java_security_cert_PKIXCertPathValidatorResult$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_PKIXCertPathValidatorResult$vtype	*vtype;
	_jc_java_security_cert_PKIXCertPathValidatorResult$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_PKIXCertPathValidatorResult$vtype _jc_java_security_cert_PKIXCertPathValidatorResult$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_PKIXCertPathValidatorResult, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_PKIXCertPathValidatorResult$class_object;

#endif	/* _JC_java_security_cert_PKIXCertPathValidatorResult_H_ */
